Options client for reading validated configuration values.
Re-exports
pub use features::FeatureChecker;pub use features::FeatureContext;pub use features::features;
Modules
Structs
- Namespace
Options - Handle for accessing options within a specific namespace.
- Options
- Options store for reading configuration values.
Enums
Functions
- init
- Initialize global options using fallback chain:
SENTRY_OPTIONS_DIRenv var, then/etc/sentry-optionsif it exists, otherwisesentry-options/. - init_
with_ propagation_ callback - Like
init, but with a callback that fires whenever values are refreshed from disk with a newgenerated_attimestamp. The callback receives(namespace, delay_secs). - init_
with_ schemas - Initialize global options with schemas provided as in-memory JSON strings. Values are loaded from disk using the standard fallback chain.
- options
- Get a namespace handle for accessing options.
Type Aliases
- Propagation
Callback - Lazily reloads values from disk when reads detect they are stale.
- Result