Module features

Module features 

Feature flag evaluation.

Provides FeatureContext and FeatureChecker for evaluating feature flags stored in the options system.

Structs

FeatureChecker
A handle for checking feature flags within a specific namespace.
FeatureContext
Application context passed to feature flag evaluation.

Functions

features
Get a feature checker handle for a namespace.