pub fn features(namespace: &str) -> FeatureCheckerExpand description
Get a feature checker handle for a namespace.
Returns a handle that returns false for all checks if init() has not been called.
pub fn features(namespace: &str) -> FeatureCheckerGet a feature checker handle for a namespace.
Returns a handle that returns false for all checks if init() has not been called.