pub fn ensure_initialized() -> Result<()>Expand description
Initialize options, ignoring “already initialized” errors.
This is useful in tests where multiple test functions may call this, but only the first one actually initializes.
Errors
Returns an error if initialization fails for reasons other than already being initialized (e.g., schema loading errors).
Example
ⓘ
use sentry_options::testing::ensure_initialized;
#[test]
fn test_something() {
ensure_initialized().unwrap();
// ... test code
}